pub struct SendSender {
pub from_pid: Pid,
pub to_pid: Pid,
pub message: Term,
}Expand description
This control message replaces the Send control message and will be sent when the distribution flag DistributionFlags::SEND_SENDER has been negotiated in the connection setup handshake.
Fields
from_pid: Pidto_pid: Pidmessage: TermTrait Implementations
Sourceimpl Clone for SendSender
impl Clone for SendSender
Sourcefn clone(&self) -> SendSender
fn clone(&self) -> SendSender
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendSender
impl Debug for SendSender
Sourceimpl PartialEq for SendSender
impl PartialEq for SendSender
impl StructuralPartialEq for SendSender