DistributionFlags

Struct DistributionFlags 

pub struct DistributionFlags(/* private fields */);
Distribution flags.

Implementations

Source

impl DistributionFlags

pub const PUBLISHED: Self

The node is to be published and part of the global namespace.

pub const ATOM_CACHE: Self

The node implements an atom cache (obsolete).

pub const EXTENDED_REFERENCES: Self

The node implements extended (3 × 32 bits) references (required).

[NOTE] This flag is mandatory. If not present, the connection is refused.

pub const DIST_MONITOR: Self

The node implements distributed process monitoring.

[NOTE] This flag will become mandatory in OTP 25.

pub const FUN_TAGS: Self

The node uses separate tag for funs (lambdas) in the distribution protocol.

pub const DIST_MONITOR_NAME: Self

The node implements distributed named process monitoring.

pub const HIDDEN_ATOM_CACHE: Self

The (hidden) node implements atom cache (obsolete).

pub const NEW_FUN_TAGS: Self

The node understands new fun tags.

[NOTE] This flag is mandatory. If not present, the connection is refused.

pub const EXTENDED_PIDS_PORTS: Self

The node can handle extended pids and ports (required).

[NOTE] This flag is mandatory. If not present, the connection is refused.

pub const EXPORT_PTR_TAG: Self

This node understands EXPORT_EXT tag.

[NOTE] This flag will become mandatory in OTP 25.

pub const BIT_BINARIES: Self

The node understands bit binaries.

[NOTE] This flag will become mandatory in OTP 25.

pub const NEW_FLOATS: Self

The node understandss new float format.

[NOTE] This flag will become mandatory in OTP 25.

pub const UNICODE_IO: Self

This node allows unicode characters in I/O operations.

pub const DIST_HDR_ATOM_CACHE: Self

The node implements atom cache in distribution header.

Note that currently erl_dist can not handle distribution headers.

pub const SMALL_ATOM_TAGS: Self

The node understands the SMALL_ATOM_EXT tag.

pub const UTF8_ATOMS: Self

The node understands UTF-8 encoded atoms.

[NOTE] This flag is mandatory. If not present, the connection is refused.

pub const MAP_TAGS: Self

The node understands maps.

[NOTE] This flag will become mandatory in OTP 25.

pub const BIG_CREATION: Self

The node understands big node creation tags NEW_PID_EXT, NEW_PORT_EXT and NEWER_REFERENCE_EXT.

[NOTE] This flag is mandatory. If not present, the connection is refused.

pub const SEND_SENDER: Self

Use the SEND_SENDER control message instead of the SEND control message and use the SEND_SENDER_TT control message instead of the SEND_TT control message.

pub const BIG_SEQTRACE_LABELS: Self

The node understands any term as the seqtrace label.

pub const EXIT_PAYLOAD: Self

Use the PAYLOAD_EXIT, PAYLOAD_EXIT_TT, PAYLOAD_EXIT2, PAYLOAD_EXIT2_TT and PAYLOAD_MONITOR_P_EXIT control messages instead of the non-PAYLOAD variants.

pub const FRAGMENTS: Self

Use fragmented distribution messages to send large messages.

pub const HANDSHAKE_23: Self

The node supports the new connection setup handshake (version 6) introduced in OTP 23.

Use the new link protocol.

Unless both nodes have set the UNLINK_ID flag, the old link protocol will be used as a fallback.

[NOTE] This flag will become mandatory in OTP 25.

pub const SPAWN: Self

Set if the SPAWN_REQUEST, SPAWN_REQUEST_TT, SPAWN_REPLY, SPAWN_REPLY_TT control messages are supported.

pub const NAME_ME: Self

Dynamic node name.

This is not a capability but rather used as a request from the connecting node to receive its node name from the accepting node as part of the handshake.

pub const V4_NC: Self

The node accepts a larger amount of data in pids, ports and references (node container types version 4).

In the pid case full 32-bit ID and Serial fields in NEW_PID_EXT, in the port case a 64-bit integer in V4_PORT_EXT, and in the reference case up to 5 32-bit ID words are now accepted in NEWER_REFERENCE_EXT. Introduced in OTP 24.

[NOTE] This flag will become mandatory in OTP 26.

pub const ALIAS: Self

The node supports process alias and can by this handle the ALIAS_SEND and ALIAS_SEND_TT control messages.

Introduced in OTP 24.

pub const MANDATORY_25_DIGEST: Self

The node supports all capabilities that are mandatory in OTP 25.

Introduced in OTP 25. [NOTE] This flag will become mandatory in OTP 27.

pub const fn bits(self) -> u64

Returns the raw bits value.

pub const fn from_bits_truncate(bits: u64) -> Self

Creates flags from raw bits.

pub const fn contains(self, other: Self) -> bool

Returns true if all flags in other are contained within self.

pub fn new() -> Self

Makes a new DistributionFlags with the default flags.

This is equivalent to the following code:

DistributionFlags::mandatory();
pub fn mandatory() -> Self

Gets the mandatory flags (in OTP 26).