pub struct DistributionFlags(/* private fields */);Expand description
Distribution flags.
Implementations
Sourceimpl DistributionFlags
impl DistributionFlags
Sourcepub const ATOM_CACHE: Self
pub const ATOM_CACHE: Self
The node implements an atom cache (obsolete).
Sourcepub const EXTENDED_REFERENCES: Self
pub const EXTENDED_REFERENCES: Self
The node implements extended (3 × 32 bits) references (required).
[NOTE] This flag is mandatory. If not present, the connection is refused.
Sourcepub const DIST_MONITOR: Self
pub const DIST_MONITOR: Self
The node implements distributed process monitoring.
[NOTE] This flag will become mandatory in OTP 25.
Sourcepub const FUN_TAGS: Self
pub const FUN_TAGS: Self
The node uses separate tag for funs (lambdas) in the distribution protocol.
Sourcepub const DIST_MONITOR_NAME: Self
pub const DIST_MONITOR_NAME: Self
The node implements distributed named process monitoring.
Sourcepub const HIDDEN_ATOM_CACHE: Self
pub const HIDDEN_ATOM_CACHE: Self
The (hidden) node implements atom cache (obsolete).
Sourcepub const NEW_FUN_TAGS: Self
pub const NEW_FUN_TAGS: Self
The node understands new fun tags.
[NOTE] This flag is mandatory. If not present, the connection is refused.
Sourcepub const EXTENDED_PIDS_PORTS: Self
pub const EXTENDED_PIDS_PORTS: Self
The node can handle extended pids and ports (required).
[NOTE] This flag is mandatory. If not present, the connection is refused.
Sourcepub const EXPORT_PTR_TAG: Self
pub const EXPORT_PTR_TAG: Self
This node understands EXPORT_EXT tag.
[NOTE] This flag will become mandatory in OTP 25.
Sourcepub const BIT_BINARIES: Self
pub const BIT_BINARIES: Self
The node understands bit binaries.
[NOTE] This flag will become mandatory in OTP 25.
Sourcepub const NEW_FLOATS: Self
pub const NEW_FLOATS: Self
The node understandss new float format.
[NOTE] This flag will become mandatory in OTP 25.
Sourcepub const UNICODE_IO: Self
pub const UNICODE_IO: Self
This node allows unicode characters in I/O operations.
Sourcepub const DIST_HDR_ATOM_CACHE: Self
pub const DIST_HDR_ATOM_CACHE: Self
The node implements atom cache in distribution header.
Note that currently erl_dist can not handle distribution headers.
Sourcepub const SMALL_ATOM_TAGS: Self
pub const SMALL_ATOM_TAGS: Self
The node understands the SMALL_ATOM_EXT tag.
Sourcepub const UTF8_ATOMS: Self
pub const UTF8_ATOMS: Self
The node understands UTF-8 encoded atoms.
[NOTE] This flag is mandatory. If not present, the connection is refused.
Sourcepub const MAP_TAGS: Self
pub const MAP_TAGS: Self
The node understands maps.
[NOTE] This flag will become mandatory in OTP 25.
Sourcepub const BIG_CREATION: Self
pub const BIG_CREATION: Self
The node understands big node creation tags NEW_PID_EXT, NEW_PORT_EXT and NEWER_REFERENCE_EXT.
[NOTE] This flag is mandatory. If not present, the connection is refused.
Sourcepub const SEND_SENDER: Self
pub const SEND_SENDER: Self
Use the SEND_SENDER control message instead of the SEND control message and use the SEND_SENDER_TT control message instead of the SEND_TT control message.
Sourcepub const BIG_SEQTRACE_LABELS: Self
pub const BIG_SEQTRACE_LABELS: Self
The node understands any term as the seqtrace label.
Sourcepub const EXIT_PAYLOAD: Self
pub const EXIT_PAYLOAD: Self
Use the PAYLOAD_EXIT, PAYLOAD_EXIT_TT, PAYLOAD_EXIT2, PAYLOAD_EXIT2_TT and PAYLOAD_MONITOR_P_EXIT control messages instead of the non-PAYLOAD variants.
Sourcepub const HANDSHAKE_23: Self
pub const HANDSHAKE_23: Self
The node supports the new connection setup handshake (version 6) introduced in OTP 23.
Sourcepub const UNLINK_ID: Self
pub const UNLINK_ID: Self
Use the new link protocol.
Unless both nodes have set the UNLINK_ID flag, the old link protocol will be used as a fallback.
[NOTE] This flag will become mandatory in OTP 25.
Sourcepub const SPAWN: Self
pub const SPAWN: Self
Set if the SPAWN_REQUEST, SPAWN_REQUEST_TT, SPAWN_REPLY, SPAWN_REPLY_TT control messages are supported.
Sourcepub const NAME_ME: Self
pub const NAME_ME: Self
Dynamic node name.
This is not a capability but rather used as a request from the connecting node to receive its node name from the accepting node as part of the handshake.
Sourcepub const V4_NC: Self
pub const V4_NC: Self
The node accepts a larger amount of data in pids, ports and references (node container types version 4).
In the pid case full 32-bit ID and Serial fields in NEW_PID_EXT,
in the port case a 64-bit integer in V4_PORT_EXT, and in the reference case up to 5 32-bit ID words are
now accepted in NEWER_REFERENCE_EXT.
Introduced in OTP 24.
[NOTE] This flag will become mandatory in OTP 26.
Sourcepub const ALIAS: Self
pub const ALIAS: Self
The node supports process alias and can by this handle the ALIAS_SEND and ALIAS_SEND_TT control messages.
Introduced in OTP 24.
Sourcepub const MANDATORY_25_DIGEST: Self
pub const MANDATORY_25_DIGEST: Self
The node supports all capabilities that are mandatory in OTP 25.
Introduced in OTP 25. [NOTE] This flag will become mandatory in OTP 27.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Creates flags from raw bits.
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Returns true if all flags in other are contained within self.
Sourcepub fn new() -> Self
pub fn new() -> Self
Makes a new DistributionFlags with the default flags.
This is equivalent to the following code:
DistributionFlags::mandatory();Trait Implementations
Sourceimpl BitAnd for DistributionFlags
impl BitAnd for DistributionFlags
Sourceimpl BitOr for DistributionFlags
impl BitOr for DistributionFlags
Sourceimpl BitOrAssign for DistributionFlags
impl BitOrAssign for DistributionFlags
Sourcefn bitor_assign(&mut self, rhs: Self)
fn bitor_assign(&mut self, rhs: Self)
|= operation. Read moreSourceimpl Clone for DistributionFlags
impl Clone for DistributionFlags
Sourcefn clone(&self) -> DistributionFlags
fn clone(&self) -> DistributionFlags
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Copy for DistributionFlags
Sourceimpl Debug for DistributionFlags
impl Debug for DistributionFlags
Sourceimpl Default for DistributionFlags
impl Default for DistributionFlags
impl Eq for DistributionFlags
Sourceimpl Hash for DistributionFlags
impl Hash for DistributionFlags
Sourceimpl PartialEq for DistributionFlags
impl PartialEq for DistributionFlags
Sourcefn eq(&self, other: &DistributionFlags) -> bool
fn eq(&self, other: &DistributionFlags) -> bool
self and other values to be equal, and is used by ==.